pub struct DeleteNamedQueryFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to DeleteNamedQuery.
Deletes the named query if you have access to the workgroup in which the query was saved.
Implementations
Sourceimpl DeleteNamedQueryFluentBuilder
impl DeleteNamedQueryFluentBuilder
Sourcepub fn as_input(&self) -> &DeleteNamedQueryInputBuilder
pub fn as_input(&self) -> &DeleteNamedQueryInputBuilder
Access the DeleteNamedQuery as a reference.
Sourcepub async fn send(
self,
) -> Result<DeleteNamedQueryOutput, SdkError<DeleteNamedQueryError, HttpResponse>>
pub async fn send( self, ) -> Result<DeleteNamedQueryOutput, SdkError<DeleteNamedQueryError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<DeleteNamedQueryOutput, DeleteNamedQueryError, Self>
pub fn customize( self, ) -> CustomizableOperation<DeleteNamedQueryOutput, DeleteNamedQueryError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn named_query_id(self, input: impl Into<String>) -> Self
pub fn named_query_id(self, input: impl Into<String>) -> Self
The unique ID of the query to delete.
Sourcepub fn set_named_query_id(self, input: Option<String>) -> Self
pub fn set_named_query_id(self, input: Option<String>) -> Self
The unique ID of the query to delete.
Sourcepub fn get_named_query_id(&self) -> &Option<String>
pub fn get_named_query_id(&self) -> &Option<String>
The unique ID of the query to delete.